@@ -1,17 +1,15 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals, absolute_import
 
 """
 Twilio REST client helpers.
 """
 
-from twilio.rest import TwilioRestClient
+from twilio.rest import Client
 
 from .settings import TWILIO_ACCOUNT_SID, TWILIO_AUTH_TOKEN
 
 
-twilio_client = TwilioRestClient(
+twilio_client = Client(
     TWILIO_ACCOUNT_SID,
     TWILIO_AUTH_TOKEN,
-    version='2010-04-01'
 )
