@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals, absolute_import
 
 """
 Useful decorators.
 """
 
-import sys
 from functools import wraps
 
 from django.conf import settings
@@ -13,20 +11,13 @@ from django.views.decorators.csrf import csrf_exempt
 from django.http import (
     HttpRequest, HttpResponse, HttpResponseForbidden, HttpResponseNotAllowed)
 
-from twilio.twiml import Verb
-from twilio.util import RequestValidator
+from twilio.twiml import TwiML as Verb
+from twilio.request_validator import RequestValidator
 
 from .settings import TWILIO_AUTH_TOKEN
 from .utils import get_blacklisted_response
 
 
-# Snippet from the `six` library to help with Python3 compatibility
-if sys.version_info[0] == 3:
-    text_type = str
-else:
-    text_type = unicode
-
-
 def twilio_view(f):
     """
     This decorator provides several helpful shortcuts for writing Twilio views.
@@ -65,7 +56,9 @@ def twilio_view(f):
     @csrf_exempt
     @wraps(f)
     def decorator(request_or_self, *args, **kwargs):
-
+        # When using `method_decorator` on class methods,
+        # I haven't been able to get any class views.
+        # i would like more research before just taking the check out.
         class_based_view = not isinstance(request_or_self, HttpRequest)
         if not class_based_view:
             request = request_or_self
@@ -114,7 +107,7 @@ def twilio_view(f):
 
         response = f(request_or_self, *args, **kwargs)
 
-        if isinstance(response, (text_type, bytes)):
+        if isinstance(response, (str, bytes)):
             return HttpResponse(response, content_type='application/xml')
         elif isinstance(response, Verb):
             return HttpResponse(str(response), content_type='application/xml')
