@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals, absolute_import
 
-from django.utils.encoding import python_2_unicode_compatible
 from django.db import models
 from django.conf import settings
 
@@ -11,7 +9,6 @@ from phonenumber_field.modelfields import PhoneNumberField
 AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
-@python_2_unicode_compatible
 class Caller(models.Model):
     """
     A caller is defined uniquely by their phone number.
@@ -31,8 +28,10 @@ class Caller(models.Model):
             blacklist_status=' (blacklisted)' if self.blacklisted else '',
         )
 
+    class Meta:
+        app_label = 'django_twilio'
+
 
-@python_2_unicode_compatible
 class Credential(models.Model):
     """
     A Credential model is a set of SID / AUTH tokens for the Twilio.com API
@@ -53,8 +52,11 @@ class Credential(models.Model):
 
     name = models.CharField(max_length=30)
 
-    user = models.OneToOneField(AUTH_USER_MODEL)
+    user = models.OneToOneField(AUTH_USER_MODEL, on_delete=models.CASCADE)
 
     account_sid = models.CharField(max_length=34)
 
     auth_token = models.CharField(max_length=32)
+
+    class Meta:
+        app_label = 'django_twilio'
