@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals, absolute_import
 
-from twilio import twiml
+from twilio.twiml.voice_response import VoiceResponse, Dial
+from twilio.twiml.messaging_response import MessagingResponse
 
 from .decorators import twilio_view
 
@@ -20,7 +20,7 @@ Usage::
         # ...
     )
     """
-    r = twiml.Response()
+    r = VoiceResponse()
     r.say(text, voice=voice, language=language, loop=loop)
     return r
 
@@ -41,7 +41,7 @@ def play(request, url, loop=None):
             # ...
         )
     """
-    r = twiml.Response()
+    r = VoiceResponse()
     r.play(url, loop=loop)
     return r
 
@@ -61,7 +61,7 @@ def gather(request, action=None, method='POST', num_digits=None, timeout=None,
             # ...
         )
     """
-    r = twiml.Response()
+    r = VoiceResponse()
     r.gather(action=action, method=method, numDigits=num_digits,
              timeout=timeout, finishOnKey=finish_on_key)
     return r
@@ -83,7 +83,7 @@ def record(request, action=None, method='POST', timeout=None,
             # ...
         )
     """
-    r = twiml.Response()
+    r = VoiceResponse()
     r.record(action=action, method=method, timeout=timeout,
              finishOnKey=finish_on_key, maxLength=max_length,
              transcribe=transcribe, transcribeCallback=transcribe_callback,
@@ -109,8 +109,8 @@ def sms(request, message, to=None, sender=None, action=None, method='POST',
             # ...
         )
     """
-    r = twiml.Response()
-    r.message(msg=message, to=to, sender=sender, method='POST', action=action,
+    r = MessagingResponse()
+    r.message(message, to=to, sender=sender, method='POST', action=action,
               statusCallback=status_callback)
     return r
 
@@ -134,8 +134,8 @@ def message(request, message, to=None, sender=None, action=None,
         )
     """
 
-    r = twiml.Response()
-    r.message(msg=message, to=to, sender=sender, method='POST',
+    r = MessagingResponse()
+    r.message(message, to=to, sender=sender, method='POST',
               action=action, statusCallback=status_callback,
               media=media)
 
@@ -147,17 +147,17 @@ def dial(request, number, action=None, method='POST', timeout=None,
          hangup_on_star=None, time_limit=None, caller_id=None):
     """
     See: http://www.twilio.com/docs/api/twiml/dial.
-
-    Usage::
-
-        # urls.py
-        urlpatterns = patterns('',
-            # ...
-            url(r'^dial/?(P<number>\\w+)/$', 'django_twilio.views.dial'),
-            # ...
-        )
     """
-    r = twiml.Response()
+    # Usage::
+    #
+    #     # urls.py
+    #     urlpatterns = patterns('',
+    #         # ...
+    #         url(r'^dial/(?P<number>\w+)/$', 'django_twilio.views.dial'),
+    #         # ...
+    #     )
+
+    r = VoiceResponse()
     r.dial(number=number, action=action, method=method, timeout=timeout,
            hangupOnStar=hangup_on_star, timeLimit=time_limit,
            callerId=caller_id)
@@ -169,22 +169,26 @@ def conference(request, name, muted=None, beep=None,
                start_conference_on_enter=None, end_conference_on_exit=None,
                wait_url=None, wait_method='POST', max_participants=None):
     """
-See: http://www.twilio.com/docs/api/twiml/conference.
-
-Usage::
-
-    # urls.py
-    urlpatterns = patterns('',
-        # ...
-        url(r'^conference/?(P<name>\\w+)/$', 'django_twilio.views.conference',
-                {'max_participants': 10}),
-        # ...
-    )
+    See: http://www.twilio.com/docs/api/twiml/conference.
     """
-    r = twiml.Response()
-    r.dial().conference(name=name, muted=muted, beep=beep,
-                        startConferenceOnEnter=start_conference_on_enter,
-                        endConferenceOnExit=end_conference_on_exit,
-                        waitUrl=wait_url, waitMethod=wait_method,
-                        )
+    # Usage::
+    #
+    #     # urls.py
+    #     urlpatterns = patterns('',
+    #         # ...
+    #         url(r'^conference/(?P<name>\w+)/$',
+    #             'django_twilio.views.conference',
+    #              {'max_participants': 10}
+    #         ),
+    #         # ...
+    #     )
+    #
+    r = VoiceResponse()
+    dial = Dial()
+    dial.conference(name=name, muted=muted, beep=beep,
+                    startConferenceOnEnter=start_conference_on_enter,
+                    endConferenceOnExit=end_conference_on_exit,
+                    waitUrl=wait_url, waitMethod=wait_method,
+                    )
+    r.append(dial)
     return r
