@@ -1,14 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals, absolute_import
 
-import sys
+from urllib.parse import urljoin
 
-if sys.version_info[0] == 3:
-    from urllib.parse import urljoin
-else:
-    from urlparse import urljoin
-
-from twilio.util import RequestValidator
+from twilio.request_validator import RequestValidator
 
 from django.test import RequestFactory
 
